import { Injectable } from '@angular/core';
import {HttpClient, HttpParams} from '@angular/common/http';
import { Observable, throwError } from 'rxjs';
import { catchError, map } from 'rxjs/operators';

@Injectable({
  providedIn: 'root'
})
export class DataService {
  private apiUrl = 'http://127.0.0.1:8080/og-lives?page=1&itemsPerPage=1000';

  constructor(private http: HttpClient) {}

  getImages(search: string = ''): Observable<any[]> {
    let url = `${this.apiUrl}`;
    if (search) {
      url += `&name=${encodeURIComponent(search)}`;
    }

    return this.http.get<any>(url).pipe(
      map(response => {
        if (response['hydra:member'] && Array.isArray(response['hydra:member'])) {
          return response['hydra:member'];
        } else {
          throw new Error('Unexpected response format');
        }
      }),
      catchError(error => {
        console.error('Error fetching images', error);
        return throwError(error);
      })
    );
  }
}
