// create-subnet.component.ts
import { HttpClient } from '@angular/common/http';
import { Component, Inject, OnInit } from '@angular/core';
import { MAT_DIALOG_DATA, MatDialogRef } from '@angular/material/dialog';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-create-subnet',
  templateUrl: './create-subnet.component.html',
  styleUrls: ['./create-subnet.component.css']
})
export class CreateSubnetComponent implements OnInit {
  name: string = '';
  netmask: string = '';
  ipAddress: string = '';
  nextServer: string = '';
  bootFileName: string = '';
  isEditMode: boolean = false;  

  constructor(
    private toastService: ToastrService,
    private http: HttpClient,
    public dialogRef: MatDialogRef<CreateSubnetComponent>,
    @Inject(MAT_DIALOG_DATA) public data: any  
  ) { }

  ngOnInit(): void {
    if (this.data && this.data.subnet) {
      this.isEditMode = true;
      this.name = this.data.subnet.name;
      this.netmask = this.data.subnet.netmask;
      this.ipAddress = this.data.subnet.ipAddress;
      this.nextServer = this.data.subnet.nextServer;
      this.bootFileName = this.data.subnet.bootFileName;
    }
  }

  onNoClick(): void {
    this.dialogRef.close();
  }

  submitForm(): void {
    const payload = {
      name: this.name,
      netmask: this.netmask,
      ipAddress: this.ipAddress,
      nextServer: this.nextServer,
      bootFileName: this.bootFileName
    };

    if (this.isEditMode) {
      this.http.patch(`http://127.0.0.1:8080/subnets/${this.data.subnet.uuid}`, payload)
        .subscribe({
          next: (response) => {
            console.log('Success:', response);
            this.toastService.success('Configuración de red actualizada exitosamente');
            this.dialogRef.close();
          },
          error: (error) => {
            console.error('Error:', error);
            this.toastService.error('Error al actualizar la configuración de red');
          }
        });
    } else {
      this.http.post('http://127.0.0.1:8080/subnets', payload)
        .subscribe({
          next: (response) => {
            console.log('Success:', response);
            this.toastService.success('Configuración de red añadida exitosamente');
            this.dialogRef.close();
          },
          error: (error) => {
            console.error('Error:', error);
            this.toastService.error('Error al añadir la configuración de red');
          }
        });
    }
  }
}
